@@ -1,10 +1,12 @@
 import logging
 import os
 import sys
+import numpy as np
 
-from pySDC.core import Hooks as hookclass
 from pySDC.core.BaseTransfer import base_transfer
 from pySDC.helpers.pysdc_helper import FrozenClass
+from pySDC.implementations.convergence_controller_classes.check_convergence import CheckConvergence
+from pySDC.implementations.hooks.default_hook import DefaultHooks
 
 
 # short helper class to add params as attributes
@@ -30,7 +32,7 @@ class controller(object):
     Base abstract controller class
     """
 
-    def __init__(self, controller_params):
+    def __init__(self, controller_params, description):
         """
         Initialization routine for the base controller
 
@@ -38,11 +40,16 @@ class controller(object):
             controller_params (dict): parameter set for the controller and the steps
         """
 
-        # check if we have a hook on this list. if not, use default class.
-        controller_params['hook_class'] = controller_params.get('hook_class', hookclass.hooks)
-        self.__hooks = controller_params['hook_class']()
+        # check if we have a hook on this list. If not, use default class.
+        self.__hooks = []
+        hook_classes = [DefaultHooks]
+        user_hooks = controller_params.get('hook_class', [])
+        hook_classes += user_hooks if type(user_hooks) == list else [user_hooks]
+        [self.add_hook(hook) for hook in hook_classes]
+        controller_params['hook_class'] = controller_params.get('hook_class', hook_classes)
 
-        self.hooks.pre_setup(step=None, level_number=None)
+        for hook in self.hooks:
+            hook.pre_setup(step=None, level_number=None)
 
         self.params = _Pars(controller_params)
 
@@ -52,6 +59,9 @@ class controller(object):
         if self.params.use_iteration_estimator and self.params.all_to_done:
             self.logger.warning('all_to_done and use_iteration_estimator set, will ignore all_to_done')
 
+        self.base_convergence_controllers = [CheckConvergence]
+        self.setup_convergence_controllers(description)
+
     @staticmethod
     def __setup_custom_logger(level=None, log_to_file=None, fname=None):
         """
@@ -68,7 +78,8 @@ class controller(object):
         # specify formats and handlers
         if log_to_file:
             file_formatter = logging.Formatter(
-                fmt='%(asctime)s - %(name)s - %(module)s - %(funcName)s - %(lineno)d - %(levelname)s: %(message)s')
+                fmt='%(asctime)s - %(name)s - %(module)s - %(funcName)s - %(lineno)d - %(levelname)s: %(message)s'
+            )
             if os.path.isfile(fname):
                 file_handler = logging.FileHandler(fname, mode='a')
             else:
@@ -95,6 +106,44 @@ class controller(object):
         else:
             pass
 
+    def add_hook(self, hook):
+        """
+        Add a hook to the controller which will be called in addition to all other hooks whenever something happens.
+        The hook is only added if a hook of the same class is not already present.
+
+        Args:
+            hook (pySDC.Hook): A hook class that is derived from the core hook class
+
+        Returns:
+            None
+        """
+        if hook not in [type(me) for me in self.hooks]:
+            self.__hooks += [hook()]
+
+    def welcome_message(self):
+        out = (
+            "Welcome to the one and only, really very astonishing and 87.3% bug free"
+            + "\n"
+            + r"                                 _____ _____   _____ "
+            + "\n"
+            + r"                                / ____|  __ \ / ____|"
+            + "\n"
+            + r"                    _ __  _   _| (___ | |  | | |     "
+            + "\n"
+            + r"                   | '_ \| | | |\___ \| |  | | |     "
+            + "\n"
+            + r"                   | |_) | |_| |____) | |__| | |____ "
+            + "\n"
+            + r"                   | .__/ \__, |_____/|_____/ \_____|"
+            + "\n"
+            + r"                   | |     __/ |                     "
+            + "\n"
+            + r"                   |_|    |___/                      "
+            + "\n"
+            + r"                                                     "
+        )
+        self.logger.info(out)
+
     def dump_setup(self, step, controller_params, description):
         """
         Helper function to dump the setup used for this controller
@@ -105,7 +154,8 @@ class controller(object):
             description (dict): description of the problem
         """
 
-        out = 'Setup overview (--> user-defined) -- BEGIN'
+        self.welcome_message()
+        out = 'Setup overview (--> user-defined, -> dependency) -- BEGIN'
         self.logger.info(out)
         out = '----------------------------------------------------------------------------------------------------\n\n'
         out += 'Controller: %s\n' % self.__class__
@@ -169,36 +219,17 @@ class controller(object):
                         out += '-->         %s = %s\n' % (k, v)
                     else:
                         out += '            %s = %s\n' % (k, v)
+
+        out += '\n'
+        out += self.get_convergence_controllers_as_table(description)
+        out += '\n'
         self.logger.info(out)
+
         out = '----------------------------------------------------------------------------------------------------'
         self.logger.info(out)
-        out = 'Setup overview (--> user-defined) -- END\n'
+        out = 'Setup overview (--> user-defined, -> dependency) -- END\n'
         self.logger.info(out)
 
-    @staticmethod
-    def check_convergence(S):
-        """
-        Routine to determine whether to stop iterating (currently testing the residual + the max. number of iterations)
-
-        Args:
-            S (pySDC.Step.step): current step
-
-        Returns:
-            bool: converged, true or false
-
-        """
-
-        # do all this on the finest level
-        L = S.levels[0]
-
-        # get residual and check against prescribed tolerance (plus check number of iterations
-        res = L.status.residual
-        converged = S.status.iter >= S.params.maxiter or res <= L.params.restol or S.status.force_done
-        if converged is None:
-            converged = False
-
-        return converged
-
     def run(self, u0, t0, Tend):
         """
         Abstract interface to the run() method
@@ -219,3 +250,92 @@ class controller(object):
             pySDC.Hooks.hooks: hooks
         """
         return self.__hooks
+
+    def setup_convergence_controllers(self, description):
+        '''
+        Setup variables needed for convergence controllers, notably a list containing all of them and a list containing
+        their order. Also, we add the `CheckConvergence` convergence controller, which takes care of maximum iteration
+        count or a residual based stopping criterion, as well as all convergence controllers added to the description.
+
+        Args:
+            description (dict): The description object used to instantiate the controller
+
+        Returns:
+            None
+        '''
+        self.convergence_controllers = []
+        self.convergence_controller_order = []
+        conv_classes = description.get('convergence_controllers', {})
+
+        # instantiate the convergence controllers
+        for conv_class, params in conv_classes.items():
+            self.add_convergence_controller(conv_class, description=description, params=params)
+
+        return None
+
+    def add_convergence_controller(self, convergence_controller, description, params=None, allow_double=False):
+        '''
+        Add an individual convergence controller to the list of convergence controllers and instantiate it.
+        Afterwards, the order of the convergence controllers is updated.
+
+        Args:
+            convergence_controller (pySDC.ConvergenceController): The convergence controller to be added
+            description (dict): The description object used to instantiate the controller
+            params (dict): Parameters for the convergence controller
+            allow_double (bool): Allow adding the same convergence controller multiple times
+
+        Returns:
+            None
+        '''
+        # check if we passed any sort of special params
+        params = {} if params is None else params
+
+        # check if we already have the convergence controller or if we want to have it multiple times
+        if convergence_controller not in [type(me) for me in self.convergence_controllers] or allow_double:
+            self.convergence_controllers.append(convergence_controller(self, params, description))
+
+            # update ordering
+            orders = [C.params.control_order for C in self.convergence_controllers]
+            self.convergence_controller_order = np.arange(len(self.convergence_controllers))[np.argsort(orders)]
+
+        return None
+
+    def get_convergence_controllers_as_table(self, description):
+        '''
+        This function is for debugging purposes to keep track of the different convergence controllers and their order.
+
+        Args:
+            description (dict): Description of the problem
+
+        Returns:
+            str: Table of convergence controllers as a string
+        '''
+        out = 'Active convergence controllers:'
+        out += '\n    |  # | order | convergence controller'
+        out += '\n----+----+-------+---------------------------------------------------------------------------------------'
+        for i in range(len(self.convergence_controllers)):
+            C = self.convergence_controllers[self.convergence_controller_order[i]]
+
+            # figure out how the convergence controller was added
+            if type(C) in description.get('convergence_controllers', {}).keys():  # added by user
+                user_added = '--> '
+            elif type(C) in self.base_convergence_controllers:  # added by default
+                user_added = '    '
+            else:  # added as dependency
+                user_added = ' -> '
+
+            out += f'\n{user_added}|{i:3} | {C.params.control_order:5} | {type(C).__name__}'
+
+        return out
+
+    def return_stats(self):
+        """
+        Return the merged stats from all hooks
+
+        Returns:
+            dict: Merged stats from all hooks
+        """
+        stats = {}
+        for hook in self.hooks:
+            stats = {**stats, **hook.return_stats()}
+        return stats
