@@ -5,7 +5,8 @@ from pySDC.helpers.pysdc_helper import FrozenClass
 class _Pars(FrozenClass):
     def __init__(self, params):
         self.dt = None
-        self.restol = 0.0
+        self.dt_initial = None
+        self.restol = -1.0
         self.nsweeps = 1
         self.residual_type = 'full_abs'
         for k, v in params.items():
@@ -13,14 +14,23 @@ class _Pars(FrozenClass):
         # freeze class, no further attributes allowed from this point
         self._freeze()
 
+        self.dt_initial = self.dt * 1.0
+
 
 # short helper class to bundle all status variables
 class _Status(FrozenClass):
+    """
+    This class carries the status of the level. All variables that the core SDC / PFASST functionality depend on are
+    initialized here, while the convergence controllers are allowed to add more variables in a controlled fashion
+    later on using the `add_variable` function.
+    """
+
     def __init__(self):
         self.residual = None
         self.unlocked = False
         self.updated = False
         self.time = None
+        self.dt_new = None
         self.sweep = None
         # freeze class, no further attributes allowed from this point
         self._freeze()
