@@ -1,10 +1,10 @@
-
 import numpy as np
 import scipy.sparse as sp
 from scipy.sparse.linalg import cg
 
 from pySDC.core.Errors import ParameterError, ProblemError
 from pySDC.core.Problem import ptype
+from pySDC.helpers import problem_helper
 from pySDC.implementations.datatype_classes.mesh import mesh, imex_mesh, comp2_mesh
 
 
@@ -31,6 +31,9 @@ class allencahn_fullyimplicit(ptype):
             dtype_f: mesh data type (will be passed parent class)
         """
 
+        if 'order' not in problem_params:
+            problem_params['order'] = 2
+
         # these parameters will be used later, so assert their existence
         essential_keys = ['nvars', 'nu', 'eps', 'newton_maxiter', 'newton_tol', 'lin_tol', 'lin_maxiter', 'radius']
         for key in essential_keys:
@@ -47,12 +50,21 @@ class allencahn_fullyimplicit(ptype):
             raise ProblemError('the setup requires nvars = 2^p per dimension')
 
         # invoke super init, passing number of dofs, dtype_u and dtype_f
-        super(allencahn_fullyimplicit, self).__init__((problem_params['nvars'], None, np.dtype('float64')),
-                                                      dtype_u, dtype_f, problem_params)
+        super(allencahn_fullyimplicit, self).__init__(
+            (problem_params['nvars'], None, np.dtype('float64')), dtype_u, dtype_f, problem_params
+        )
 
         # compute dx and get discretization matrix A
         self.dx = 1.0 / self.params.nvars[0]
-        self.A = self.__get_A(self.params.nvars, self.dx)
+        self.A = problem_helper.get_finite_difference_matrix(
+            derivative=2,
+            order=self.params.order,
+            type='center',
+            dx=self.dx,
+            size=self.params.nvars[0],
+            dim=2,
+            bc='periodic',
+        )
         self.xvalues = np.array([i * self.dx - 0.5 for i in range(self.params.nvars[0])])
 
         self.newton_itercount = 0
@@ -75,15 +87,19 @@ class allencahn_fullyimplicit(ptype):
 
         stencil = [1, -2, 1]
         zero_pos = 2
+
         dstencil = np.concatenate((stencil, np.delete(stencil, zero_pos - 1)))
-        offsets = np.concatenate(([N[0] - i - 1 for i in reversed(range(zero_pos - 1))],
-                                  [i - zero_pos + 1 for i in range(zero_pos - 1, len(stencil))]))
+        offsets = np.concatenate(
+            (
+                [N[0] - i - 1 for i in reversed(range(zero_pos - 1))],
+                [i - zero_pos + 1 for i in range(zero_pos - 1, len(stencil))],
+            )
+        )
         doffsets = np.concatenate((offsets, np.delete(offsets, zero_pos - 1) - N[0]))
 
         A = sp.diags(dstencil, doffsets, shape=(N[0], N[0]), format='csc')
         A = sp.kron(A, sp.eye(N[0])) + sp.kron(sp.eye(N[1]), A)
-        A *= 1.0 / (dx ** 2)
-
+        A *= 1.0 / (dx**2)
         return A
 
     # noinspection PyTypeChecker
@@ -104,7 +120,7 @@ class allencahn_fullyimplicit(ptype):
         u = self.dtype_u(u0).flatten()
         z = self.dtype_u(self.init, val=0.0).flatten()
         nu = self.params.nu
-        eps2 = self.params.eps ** 2
+        eps2 = self.params.eps**2
 
         Id = sp.eye(self.params.nvars[0] * self.params.nvars[1])
 
@@ -114,7 +130,7 @@ class allencahn_fullyimplicit(ptype):
         while n < self.params.newton_maxiter:
 
             # form the function g with g(u) = 0
-            g = u - factor * (self.A.dot(u) + 1.0 / eps2 * u * (1.0 - u ** nu)) - rhs.flatten()
+            g = u - factor * (self.A.dot(u) + 1.0 / eps2 * u * (1.0 - u**nu)) - rhs.flatten()
 
             # if g is close to 0, then we are done
             res = np.linalg.norm(g, np.inf)
@@ -123,11 +139,11 @@ class allencahn_fullyimplicit(ptype):
                 break
 
             # assemble dg
-            dg = Id - factor * (self.A + 1.0 / eps2 * sp.diags((1.0 - (nu + 1) * u ** nu), offsets=0))
+            dg = Id - factor * (self.A + 1.0 / eps2 * sp.diags((1.0 - (nu + 1) * u**nu), offsets=0))
 
             # newton update: u1 = u0 - g/dg
             # u -= spsolve(dg, g)
-            u -= cg(dg, g, x0=z, tol=self.params.lin_tol)[0]
+            u -= cg(dg, g, x0=z, tol=self.params.lin_tol, atol=0)[0]
             # increase iteration count
             n += 1
             # print(n, res)
@@ -156,7 +172,7 @@ class allencahn_fullyimplicit(ptype):
         """
         f = self.dtype_f(self.init)
         v = u.flatten()
-        f[:] = (self.A.dot(v) + 1.0 / self.params.eps ** 2 * v * (1.0 - v ** self.params.nu)).reshape(self.params.nvars)
+        f[:] = (self.A.dot(v) + 1.0 / self.params.eps**2 * v * (1.0 - v**self.params.nu)).reshape(self.params.nvars)
 
         return f
 
@@ -214,7 +230,7 @@ class allencahn_semiimplicit(allencahn_fullyimplicit):
         f = self.dtype_f(self.init)
         v = u.flatten()
         f.impl[:] = self.A.dot(v).reshape(self.params.nvars)
-        f.expl[:] = (1.0 / self.params.eps ** 2 * v * (1.0 - v ** self.params.nu)).reshape(self.params.nvars)
+        f.expl[:] = (1.0 / self.params.eps**2 * v * (1.0 - v**self.params.nu)).reshape(self.params.nvars)
 
         return f
 
@@ -243,8 +259,15 @@ class allencahn_semiimplicit(allencahn_fullyimplicit):
 
         Id = sp.eye(self.params.nvars[0] * self.params.nvars[1])
 
-        me[:] = cg(Id - factor * self.A, rhs.flatten(), x0=u0.flatten(), tol=self.params.lin_tol,
-                   maxiter=self.params.lin_maxiter, callback=callback)[0].reshape(self.params.nvars)
+        me[:] = cg(
+            Id - factor * self.A,
+            rhs.flatten(),
+            x0=u0.flatten(),
+            tol=self.params.lin_tol,
+            maxiter=self.params.lin_maxiter,
+            atol=0,
+            callback=callback,
+        )[0].reshape(self.params.nvars)
 
         self.lin_ncalls += 1
         self.lin_itercount += context.num_iter
@@ -284,8 +307,8 @@ class allencahn_semiimplicit_v2(allencahn_fullyimplicit):
         """
         f = self.dtype_f(self.init)
         v = u.flatten()
-        f.impl[:] = (self.A.dot(v) - 1.0 / self.params.eps ** 2 * v ** (self.params.nu + 1)).reshape(self.params.nvars)
-        f.expl[:] = (1.0 / self.params.eps ** 2 * v).reshape(self.params.nvars)
+        f.impl[:] = (self.A.dot(v) - 1.0 / self.params.eps**2 * v ** (self.params.nu + 1)).reshape(self.params.nvars)
+        f.expl[:] = (1.0 / self.params.eps**2 * v).reshape(self.params.nvars)
 
         return f
 
@@ -306,7 +329,7 @@ class allencahn_semiimplicit_v2(allencahn_fullyimplicit):
         u = self.dtype_u(u0).flatten()
         z = self.dtype_u(self.init, val=0.0).flatten()
         nu = self.params.nu
-        eps2 = self.params.eps ** 2
+        eps2 = self.params.eps**2
 
         Id = sp.eye(self.params.nvars[0] * self.params.nvars[1])
 
@@ -319,17 +342,18 @@ class allencahn_semiimplicit_v2(allencahn_fullyimplicit):
             g = u - factor * (self.A.dot(u) - 1.0 / eps2 * u ** (nu + 1)) - rhs.flatten()
 
             # if g is close to 0, then we are done
+            # res = np.linalg.norm(g, np.inf)
             res = np.linalg.norm(g, np.inf)
 
             if res < self.params.newton_tol:
                 break
 
             # assemble dg
-            dg = Id - factor * (self.A - 1.0 / eps2 * sp.diags(((nu + 1) * u ** nu), offsets=0))
+            dg = Id - factor * (self.A - 1.0 / eps2 * sp.diags(((nu + 1) * u**nu), offsets=0))
 
             # newton update: u1 = u0 - g/dg
             # u -= spsolve(dg, g)
-            u -= cg(dg, g, x0=z, tol=self.params.lin_tol)[0]
+            u -= cg(dg, g, x0=z, tol=self.params.lin_tol, atol=0)[0]
             # increase iteration count
             n += 1
             # print(n, res)
@@ -379,7 +403,7 @@ class allencahn_multiimplicit(allencahn_fullyimplicit):
         f = self.dtype_f(self.init)
         v = u.flatten()
         f.comp1[:] = self.A.dot(v).reshape(self.params.nvars)
-        f.comp2[:] = (1.0 / self.params.eps ** 2 * v * (1.0 - v ** self.params.nu)).reshape(self.params.nvars)
+        f.comp2[:] = (1.0 / self.params.eps**2 * v * (1.0 - v**self.params.nu)).reshape(self.params.nvars)
 
         return f
 
@@ -408,8 +432,15 @@ class allencahn_multiimplicit(allencahn_fullyimplicit):
 
         Id = sp.eye(self.params.nvars[0] * self.params.nvars[1])
 
-        me[:] = cg(Id - factor * self.A, rhs.flatten(), x0=u0.flatten(), tol=self.params.lin_tol,
-                   maxiter=self.params.lin_maxiter, callback=callback)[0].reshape(self.params.nvars)
+        me[:] = cg(
+            Id - factor * self.A,
+            rhs.flatten(),
+            x0=u0.flatten(),
+            tol=self.params.lin_tol,
+            maxiter=self.params.lin_maxiter,
+            atol=0,
+            callback=callback,
+        )[0].reshape(self.params.nvars)
 
         self.lin_ncalls += 1
         self.lin_itercount += context.num_iter
@@ -433,7 +464,7 @@ class allencahn_multiimplicit(allencahn_fullyimplicit):
         u = self.dtype_u(u0).flatten()
         z = self.dtype_u(self.init, val=0.0).flatten()
         nu = self.params.nu
-        eps2 = self.params.eps ** 2
+        eps2 = self.params.eps**2
 
         Id = sp.eye(self.params.nvars[0] * self.params.nvars[1])
 
@@ -443,7 +474,7 @@ class allencahn_multiimplicit(allencahn_fullyimplicit):
         while n < self.params.newton_maxiter:
 
             # form the function g with g(u) = 0
-            g = u - factor * (1.0 / eps2 * u * (1.0 - u ** nu)) - rhs.flatten()
+            g = u - factor * (1.0 / eps2 * u * (1.0 - u**nu)) - rhs.flatten()
 
             # if g is close to 0, then we are done
             res = np.linalg.norm(g, np.inf)
@@ -452,11 +483,11 @@ class allencahn_multiimplicit(allencahn_fullyimplicit):
                 break
 
             # assemble dg
-            dg = Id - factor * (1.0 / eps2 * sp.diags((1.0 - (nu + 1) * u ** nu), offsets=0))
+            dg = Id - factor * (1.0 / eps2 * sp.diags((1.0 - (nu + 1) * u**nu), offsets=0))
 
             # newton update: u1 = u0 - g/dg
             # u -= spsolve(dg, g)
-            u -= cg(dg, g, x0=z, tol=self.params.lin_tol)[0]
+            u -= cg(dg, g, x0=z, tol=self.params.lin_tol, atol=0)[0]
             # increase iteration count
             n += 1
             # print(n, res)
@@ -505,8 +536,8 @@ class allencahn_multiimplicit_v2(allencahn_fullyimplicit):
         """
         f = self.dtype_f(self.init)
         v = u.flatten()
-        f.comp1[:] = (self.A.dot(v) - 1.0 / self.params.eps ** 2 * v ** (self.params.nu + 1)).reshape(self.params.nvars)
-        f.comp2[:] = (1.0 / self.params.eps ** 2 * v).reshape(self.params.nvars)
+        f.comp1[:] = (self.A.dot(v) - 1.0 / self.params.eps**2 * v ** (self.params.nu + 1)).reshape(self.params.nvars)
+        f.comp2[:] = (1.0 / self.params.eps**2 * v).reshape(self.params.nvars)
 
         return f
 
@@ -527,7 +558,7 @@ class allencahn_multiimplicit_v2(allencahn_fullyimplicit):
         u = self.dtype_u(u0).flatten()
         z = self.dtype_u(self.init, val=0.0).flatten()
         nu = self.params.nu
-        eps2 = self.params.eps ** 2
+        eps2 = self.params.eps**2
 
         Id = sp.eye(self.params.nvars[0] * self.params.nvars[1])
 
@@ -546,11 +577,17 @@ class allencahn_multiimplicit_v2(allencahn_fullyimplicit):
                 break
 
             # assemble dg
-            dg = Id - factor * (self.A - 1.0 / eps2 * sp.diags(((nu + 1) * u ** nu), offsets=0))
+            dg = Id - factor * (self.A - 1.0 / eps2 * sp.diags(((nu + 1) * u**nu), offsets=0))
 
             # newton update: u1 = u0 - g/dg
             # u -= spsolve(dg, g)
-            u -= cg(dg, g, x0=z, tol=self.params.lin_tol)[0]
+            u -= cg(
+                dg,
+                g,
+                x0=z,
+                tol=self.params.lin_tol,
+                atol=0,
+            )[0]
             # increase iteration count
             n += 1
             # print(n, res)
@@ -582,5 +619,5 @@ class allencahn_multiimplicit_v2(allencahn_fullyimplicit):
 
         me = self.dtype_u(self.init)
 
-        me[:] = (1.0 / (1.0 - factor * 1.0 / self.params.eps ** 2) * rhs).reshape(self.params.nvars)
+        me[:] = (1.0 / (1.0 - factor * 1.0 / self.params.eps**2) * rhs).reshape(self.params.nvars)
         return me
