@@ -1,7 +1,7 @@
 import numpy as np
 
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.helpers.stats_helper import get_sorted
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.problem_classes.TestEquation_0D import testequation0d
 from pySDC.implementations.sweeper_classes.generic_implicit import generic_implicit
@@ -23,7 +23,7 @@ def testequation_setup(prec_type=None, maxiter=None):
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = [5]
     sweeper_params['QI'] = prec_type
     sweeper_params['initial_guess'] = 'spread'
@@ -76,8 +76,12 @@ def compare_preconditioners(f=None, list_of_k=None):
         print(out)
 
         # instantiate controller
-        controller_IE = controller_nonMPI(num_procs=1, controller_params=controller_params_IE, description=description_IE)
-        controller_LU = controller_nonMPI(num_procs=1, controller_params=controller_params_LU, description=description_LU)
+        controller_IE = controller_nonMPI(
+            num_procs=1, controller_params=controller_params_IE, description=description_IE
+        )
+        controller_LU = controller_nonMPI(
+            num_procs=1, controller_params=controller_params_LU, description=description_LU
+        )
 
         # get initial values on finest level
         P = controller_IE.MS[0].levels[0].prob
@@ -100,13 +104,9 @@ def compare_preconditioners(f=None, list_of_k=None):
         f.write(out + '\n')
         print(out)
 
-        # filter statistics by type
-        filtered_stats_IE = filter_stats(stats_IE, type='error_after_step')
-        filtered_stats_LU = filter_stats(stats_LU, type='error_after_step')
-
         # convert filtered statistics to list
-        errors_IE = sort_stats(filtered_stats_IE, sortby='time')
-        errors_LU = sort_stats(filtered_stats_LU, sortby='time')
+        errors_IE = get_sorted(stats_IE, type='error_after_step', sortby='time')
+        errors_LU = get_sorted(stats_LU, type='error_after_step', sortby='time')
         print(errors_IE)
         print(errors_LU)
 
