@@ -25,5 +25,7 @@ class error_output(hooks):
         uex = P.u_exact(step.time + step.dt)
         err = abs(uex - L.uend)
 
-        print('--- Current error (vs. exact solution) at iteration %2i and time %4.2f: %6.4e' %
-              (step.status.iter, step.time, err))
+        print(
+            '--- Current error (vs. exact solution) at iteration %2i and time %4.2f: %6.4e'
+            % (step.status.iter, step.time, err)
+        )
