@@ -4,7 +4,6 @@ from pySDC.core.Hooks import hooks
 
 
 class monitor(hooks):
-
     def pre_run(self, step, level_number):
         """
         Overwrite standard post step hook
@@ -21,9 +20,15 @@ class monitor(hooks):
         bx_max = np.amax(abs(L.u[0][..., 0]))
         # bx_max = np.amax(abs(L.u[0].values[0]['g']))
 
-        self.add_to_stats(process=step.status.slot, time=L.time, level=-1, iter=step.status.iter,
-                          sweep=L.status.sweep, type='bx_max', value=bx_max)
-
+        self.add_to_stats(
+            process=step.status.slot,
+            time=L.time,
+            level=-1,
+            iter=step.status.iter,
+            sweep=L.status.sweep,
+            type='bx_max',
+            value=bx_max,
+        )
 
     def post_step(self, step, level_number):
         """
@@ -41,5 +46,12 @@ class monitor(hooks):
         bx_max = np.amax(abs(L.uend[..., 0]))
         # bx_max = np.amax(abs(L.uend.values[0]['g']))
 
-        self.add_to_stats(process=step.status.slot, time=L.time + L.dt, level=-1, iter=step.status.iter,
-                          sweep=L.status.sweep, type='bx_max', value=bx_max)
+        self.add_to_stats(
+            process=step.status.slot,
+            time=L.time + L.dt,
+            level=-1,
+            iter=step.status.iter,
+            sweep=L.status.sweep,
+            type='bx_max',
+            value=bx_max,
+        )
