@@ -2,8 +2,8 @@ from argparse import ArgumentParser
 import numpy as np
 from mpi4py import MPI
 
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.helpers.stats_helper import get_sorted
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.sweeper_classes.imex_1st_order import imex_1st_order
 from pySDC.implementations.problem_classes.AllenCahn_Temp_MPIFFT import allencahn_temp_imex
@@ -40,13 +40,13 @@ def run_simulation(name='', spectral=None, nprocs_space=None):
 
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-12
-    level_params['dt'] = 1E-06
+    level_params['restol'] = 1e-12
+    level_params['dt'] = 1e-06
     level_params['nsweeps'] = [1]
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = [7]
     sweeper_params['QI'] = ['LU']  # For the IMEX sweeper, the LU-trick can be activated for the implicit part
     sweeper_params['initial_guess'] = 'spread'
@@ -106,18 +106,18 @@ def run_simulation(name='', spectral=None, nprocs_space=None):
         print()
 
         # convert filtered statistics of iterations count, sorted by time
-        iter_counts = sort_stats(filter_stats(stats, type='niter'), sortby='time')
+        iter_counts = get_sorted(stats, type='niter', sortby='time')
         niters = np.mean(np.array([item[1] for item in iter_counts]))
         out = f'Mean number of iterations: {niters:.4f}'
         print(out)
 
         # get setup time
-        timing = sort_stats(filter_stats(stats, type='timing_setup'), sortby='time')
+        timing = get_sorted(stats, type='timing_setup', sortby='time')
         out = f'Setup time: {timing[0][1]:.4f} sec.'
         print(out)
 
         # get running time
-        timing = sort_stats(filter_stats(stats, type='timing_run'), sortby='time')
+        timing = get_sorted(stats, type='timing_run', sortby='time')
         out = f'Time to solution: {timing[0][1]:.4f} sec.'
         print(out)
 
