@@ -6,11 +6,11 @@ import os
 import matplotlib.pyplot as plt
 import numpy as np
 
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.helpers.stats_helper import get_sorted
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
-from pySDC.implementations.problem_classes.AdvectionEquation_1D_FD import advection1d
-from pySDC.implementations.problem_classes.HeatEquation_1D_FD import heat1d
+from pySDC.implementations.problem_classes.AdvectionEquation_ND_FD import advectionNd
+from pySDC.implementations.problem_classes.HeatEquation_ND_FD import heatNd_unforced
 from pySDC.implementations.sweeper_classes.generic_implicit import generic_implicit
 from pySDC.implementations.transfer_classes.TransferMesh import mesh_to_mesh
 
@@ -30,22 +30,23 @@ def main():
     plot_results()
 
 
-def run_diffusion(QI):
+def run_diffusion(QI, max_proc_exp=13):
     """
     A simple test program to test PFASST convergence for the heat equation with random initial data
 
     Args:
         QI: preconditioner
+        max_proc_exp: max number of processors will be 2^max_proc_exp
     """
 
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-08
+    level_params['restol'] = 1e-08
     level_params['nsweeps'] = [3, 1]
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = [3]
     sweeper_params['QI'] = [QI, 'LU']
     sweeper_params['initial_guess'] = 'zero'
@@ -53,8 +54,9 @@ def run_diffusion(QI):
     # initialize problem parameters
     problem_params = dict()
     problem_params['nu'] = 0.1  # diffusion coefficient
-    problem_params['freq'] = -1  # frequency for the test value
+    problem_params['freq'] = 2  # frequency for the test value
     problem_params['nvars'] = [127, 63]  # number of degrees of freedom for each level
+    problem_params['bc'] = 'dirichlet-zero'  # boundary conditions
 
     # initialize step parameters
     step_params = dict()
@@ -72,7 +74,7 @@ def run_diffusion(QI):
 
     # fill description dictionary for easy step instantiation
     description = dict()
-    description['problem_class'] = heat1d  # pass problem class
+    description['problem_class'] = heatNd_unforced  # pass problem class
     description['problem_params'] = problem_params  # pass problem parameters
     description['sweeper_class'] = generic_implicit  # pass sweeper (see part B)
     description['sweeper_params'] = sweeper_params  # pass sweeper parameters
@@ -92,9 +94,9 @@ def run_diffusion(QI):
     writer.writerow(('num_proc', 'niter'))
     file.close()
 
-    for i in range(0, 13):
+    for i in range(0, max_proc_exp):
 
-        num_proc = 2 ** i
+        num_proc = 2**i
         level_params['dt'] = (Tend - t0) / num_proc
         description['level_params'] = level_params  # pass level parameters
 
@@ -115,10 +117,7 @@ def run_diffusion(QI):
         uend, stats = controller.run(u0=uinit, t0=t0, Tend=Tend)
 
         # filter statistics by type (number of iterations)
-        filtered_stats = filter_stats(stats, type='niter')
-
-        # convert filtered statistics to list of iterations count, sorted by process
-        iter_counts = sort_stats(filtered_stats, sortby='time')
+        iter_counts = get_sorted(stats, type='niter', sortby='time')
 
         niters = np.array([item[1] for item in iter_counts])
 
@@ -133,22 +132,23 @@ def run_diffusion(QI):
     assert os.path.isfile(fname), 'ERROR: pickle did not create file'
 
 
-def run_advection(QI):
+def run_advection(QI, max_proc_exp=7):
     """
     A simple test program to test PFASST convergence for the periodic advection equation
 
     Args:
         QI: preconditioner
+        max_proc_exp: max number of processors will be 2^max_proc_exp
     """
 
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-08
+    level_params['restol'] = 1e-08
     level_params['nsweeps'] = [3, 1]
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = [3]
     sweeper_params['QI'] = [QI, 'LU']  # For the IMEX sweeper, the LU-trick can be activated for the implicit part
     sweeper_params['initial_guess'] = 'zero'
@@ -160,6 +160,7 @@ def run_advection(QI):
     problem_params['order'] = 2
     problem_params['type'] = 'center'
     problem_params['c'] = 0.1
+    problem_params['bc'] = 'periodic'  # boundary conditions
 
     # initialize step parameters
     step_params = dict()
@@ -177,7 +178,7 @@ def run_advection(QI):
 
     # fill description dictionary for easy step instantiation
     description = dict()
-    description['problem_class'] = advection1d  # pass problem class
+    description['problem_class'] = advectionNd  # pass problem class
     description['problem_params'] = problem_params  # pass problem parameters
     description['sweeper_class'] = generic_implicit  # pass sweeper (see part B)
     description['sweeper_params'] = sweeper_params  # pass sweeper parameters
@@ -197,9 +198,9 @@ def run_advection(QI):
     writer.writerow(('num_proc', 'niter'))
     file.close()
 
-    for i in range(0, 7):
+    for i in range(0, max_proc_exp):
 
-        num_proc = 2 ** i
+        num_proc = 2**i
         level_params['dt'] = (Tend - t0) / num_proc
         description['level_params'] = level_params  # pass level parameters
 
@@ -220,10 +221,7 @@ def run_advection(QI):
         uend, stats = controller.run(u0=uinit, t0=t0, Tend=Tend)
 
         # filter statistics by type (number of iterations)
-        filtered_stats = filter_stats(stats, type='niter')
-
-        # convert filtered statistics to list of iterations count, sorted by process
-        iter_counts = sort_stats(filtered_stats, sortby='time')
+        iter_counts = get_sorted(stats, type='niter', sortby='time')
 
         niters = np.array([item[1] for item in iter_counts])
 
@@ -271,14 +269,15 @@ def plot_results(cwd=''):
         file.close()
 
         # set up plotting parameters
-        params = {'legend.fontsize': 20,
-                  'figure.figsize': (12, 8),
-                  'axes.labelsize': 20,
-                  'axes.titlesize': 20,
-                  'xtick.labelsize': 16,
-                  'ytick.labelsize': 16,
-                  'lines.linewidth': 3
-                  }
+        params = {
+            'legend.fontsize': 20,
+            'figure.figsize': (12, 8),
+            'axes.labelsize': 20,
+            'axes.titlesize': 20,
+            'xtick.labelsize': 16,
+            'ytick.labelsize': 16,
+            'lines.linewidth': 3,
+        }
         plt.rcParams.update(params)
 
         # set up figure
