@@ -6,7 +6,7 @@ matplotlib.use('Agg')
 import matplotlib.pylab as plt
 from matplotlib import rc
 
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.core.Collocation import CollBase
 
 
 def compute_and_plot_specrad(Nnodes, lam):
@@ -20,7 +20,7 @@ def compute_and_plot_specrad(Nnodes, lam):
 
     Nsteps = 1
 
-    coll = CollGaussRadau_Right(Nnodes, 0, 1)
+    coll = CollBase(Nnodes, 0, 1, quad_type='RADAU-RIGHT')
     Qmat = coll.Qmat[1:, 1:]
 
     # do LU decomposition of QT (St. Martin's trick)
@@ -37,7 +37,7 @@ def compute_and_plot_specrad(Nnodes, lam):
 
     setup_list = zip(Nsweep_list, color_list, marker_list)
 
-    xlist = [10 ** i for i in range(11)]
+    xlist = [10**i for i in range(11)]
 
     rc('font', **{"sans-serif": ["Arial"], "size": 24})
     plt.subplots(figsize=(15, 10))
@@ -52,27 +52,47 @@ def compute_and_plot_specrad(Nnodes, lam):
         for x in xlist:
 
             mat = np.linalg.inv(np.eye(Nnodes * Nsteps) - x * lam * np.kron(np.eye(Nsteps), QDmat)).dot(
-                x * lam * np.kron(np.eye(Nsteps), (Qmat - QDmat)) + np.kron(Emat, Nmat))
+                x * lam * np.kron(np.eye(Nsteps), (Qmat - QDmat)) + np.kron(Emat, Nmat)
+            )
             mat = np.linalg.matrix_power(mat, Nsweeps)
 
             Prho_list.append(max(abs(np.linalg.eigvals(mat))))
             predict_list.append(1.0 / x)
 
             if len(predict_list) > 1:
-                print(x, predict_list[-1], Prho_list[-1], Prho_list[-2] / Prho_list[-1],
-                      predict_list[-2] / predict_list[-1])
+                print(
+                    x,
+                    predict_list[-1],
+                    Prho_list[-1],
+                    Prho_list[-2] / Prho_list[-1],
+                    predict_list[-2] / predict_list[-1],
+                )
 
-        plt.loglog(xlist, Prho_list, linestyle='-', linewidth=3, color=color, marker=marker, markersize=10,
-                   label='spectral radius, L=' + str(Nsteps))
+        plt.loglog(
+            xlist,
+            Prho_list,
+            linestyle='-',
+            linewidth=3,
+            color=color,
+            marker=marker,
+            markersize=10,
+            label='spectral radius, L=' + str(Nsteps),
+        )
 
-    plt.loglog(xlist, [item / predict_list[0] for item in predict_list], linestyle='--', linewidth=2, color='k',
-               label='estimate')
+    plt.loglog(
+        xlist,
+        [item / predict_list[0] for item in predict_list],
+        linestyle='--',
+        linewidth=2,
+        color='k',
+        label='estimate',
+    )
 
     plt.xlabel('time-step size')
     plt.ylabel('spectral radius')
     plt.legend(loc=3, numpoints=1)
     plt.grid()
-    plt.ylim([1E-16, 1E00])
+    plt.ylim([1e-16, 1e00])
 
     if type(lam) is complex:
         fname = 'data/smoother_specrad_toinf_M' + str(Nnodes) + '_LU_imag.png'
