@@ -6,7 +6,7 @@ matplotlib.use('Agg')
 import matplotlib.pyplot as plt
 from matplotlib.colors import LogNorm
 
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.core.Collocation import CollBase
 
 
 def compute_and_plot_specrad():
@@ -21,20 +21,21 @@ def compute_and_plot_specrad():
     # setup_list = [('EX', 'to0'), ('PIC', 'to0')]
 
     # set up plotting parameters
-    params = {'legend.fontsize': 24,
-              'figure.figsize': (12, 8),
-              'axes.labelsize': 24,
-              'axes.titlesize': 24,
-              'xtick.labelsize': 24,
-              'ytick.labelsize': 24,
-              'lines.linewidth': 3
-              }
+    params = {
+        'legend.fontsize': 24,
+        'figure.figsize': (12, 8),
+        'axes.labelsize': 24,
+        'axes.titlesize': 24,
+        'xtick.labelsize': 24,
+        'ytick.labelsize': 24,
+        'lines.linewidth': 3,
+    }
     plt.rcParams.update(params)
 
     Nnodes = 3
     Nsteps = 4
 
-    coll = CollGaussRadau_Right(Nnodes, 0, 1)
+    coll = CollBase(Nnodes, 0, 1, quad_type='RADAU-RIGHT')
     Qmat = coll.Qmat[1:, 1:]
 
     Nmat = np.zeros((Nnodes, Nnodes))
@@ -55,7 +56,7 @@ def compute_and_plot_specrad():
 
             QI = np.zeros(np.shape(coll.Qmat))
             for m in range(coll.num_nodes + 1):
-                QI[m, 1:m + 1] = coll.delta_m[0:m]
+                QI[m, 1 : m + 1] = coll.delta_m[0:m]
             QDmat = QI[1:, 1:]
 
         elif qd_type == 'EE':
@@ -121,7 +122,8 @@ def compute_and_plot_specrad():
                 dxlam = rlam + ilam
 
                 mat = np.linalg.inv(np.eye(Nnodes * Nsteps) - dxlam * np.kron(np.eye(Nsteps), QDmat)).dot(
-                    dxlam * np.kron(np.eye(Nsteps), (Qmat - QDmat)) + np.kron(Emat, Nmat))
+                    dxlam * np.kron(np.eye(Nsteps), (Qmat - QDmat)) + np.kron(Emat, Nmat)
+                )
                 mat = np.linalg.matrix_power(mat, Nnodes)
 
                 Prho[idr, idi] = max(abs(np.linalg.eigvals(mat)))
@@ -131,22 +133,25 @@ def compute_and_plot_specrad():
         fig, ax = plt.subplots(figsize=(15, 10))
 
         ax.set_xticks([i + 0.5 for i in range(0, len(rlam_list), int(len(rlam_list) / 5))])
-        ax.set_xticklabels([r'-$10^{%d}$' % i for i in range(rlim_left, rlim_right,
-                                                             int((rlim_right - rlim_left + 1) / 5))])
+        ax.set_xticklabels(
+            [r'-$10^{%d}$' % i for i in range(rlim_left, rlim_right, int((rlim_right - rlim_left + 1) / 5))]
+        )
         ax.set_yticks([i + 0.5 for i in range(0, len(ilam_list), int(len(ilam_list) / 5))])
-        ax.set_yticklabels([r'$10^{%d}i$' % i for i in range(ilim_left, ilim_right,
-                                                             int((ilim_right - ilim_left - 1) / 5))])
+        ax.set_yticklabels(
+            [r'$10^{%d}i$' % i for i in range(ilim_left, ilim_right, int((ilim_right - ilim_left - 1) / 5))]
+        )
 
         cmap = plt.get_cmap('Reds')
-        pcol = plt.pcolor(Prho.T, cmap=cmap, norm=LogNorm(vmin=1E-09, vmax=1E-00))
+        pcol = plt.pcolor(Prho.T, cmap=cmap, norm=LogNorm(vmin=1e-09, vmax=1e-00))
 
         plt.colorbar(pcol)
 
         plt.xlabel(r'$Re(\Delta t\lambda)$')
         plt.ylabel(r'$Im(\Delta t\lambda)$')
 
-        fname = 'data/heatmap_smoother_' + conv_type + '_Nsteps' + str(Nsteps) + '_M' + \
-                str(Nnodes) + '_' + qd_type + '.png'
+        fname = (
+            'data/heatmap_smoother_' + conv_type + '_Nsteps' + str(Nsteps) + '_M' + str(Nnodes) + '_' + qd_type + '.png'
+        )
         plt.savefig(fname, transparent=True, bbox_inches='tight')
 
 
