@@ -7,7 +7,7 @@ from matplotlib import pyplot as plt
 from pylab import rcParams
 
 from pySDC.projects.FastWaveSlowWave.HookClass_acoustic import dump_energy
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+
 from pySDC.implementations.sweeper_classes.imex_1st_order import imex_1st_order
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.problem_classes.acoustic_helpers.standard_integrators import bdf2, dirk, trapezoidal, rk_imex
@@ -29,7 +29,7 @@ def compute_and_plot_solutions():
 
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-10
+    level_params['restol'] = 1e-10
     level_params['dt'] = dt
 
     # This comes as read-in for the step class
@@ -46,7 +46,7 @@ def compute_and_plot_solutions():
 
     # This comes as read-in for the sweeper class
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 2
 
     # initialize controller parameters
@@ -64,8 +64,7 @@ def compute_and_plot_solutions():
     description['level_params'] = level_params
 
     # instantiate the controller
-    controller = controller_nonMPI(num_procs=num_procs, controller_params=controller_params,
-                                   description=description)
+    controller = controller_nonMPI(num_procs=num_procs, controller_params=controller_params, description=description)
 
     # get initial values on finest level
     P = controller.MS[0].levels[0].prob
@@ -127,6 +126,10 @@ def compute_and_plot_solutions():
     x_0 = 0.75
     # x_1 = 0.25
 
+    assert np.isclose(np.linalg.norm(uend[1, :], np.inf), 8.489e-01, 1e-03)
+    assert np.isclose(np.linalg.norm(pnew_dirk, np.inf), 1.003e00, 1e-03)
+    assert np.isclose(np.linalg.norm(pnew_imex, np.inf), 2.762e21, 1e-03)
+
     print('Maximum pressure in SDC: %5.3e' % np.linalg.norm(uend[1, :], np.inf))
     print('Maximum pressure in DIRK: %5.3e' % np.linalg.norm(pnew_dirk, np.inf))
     print('Maximum pressure in RK-IMEX: %5.3e' % np.linalg.norm(pnew_imex, np.inf))
@@ -136,11 +139,11 @@ def compute_and_plot_solutions():
     p_slow = np.exp(-np.square(np.mod(P.mesh - problem_params['cadv'] * Tend, 1.0) - x_0) / (sigma_0 * sigma_0))
     plt.plot(P.mesh, p_slow, '--', color='k', markersize=fs - 2, label='Slow mode', dashes=(10, 2))
     if np.linalg.norm(pnew_imex, np.inf) <= 2:
-        plt.plot(P.mesh, pnew_imex, '+-', color='r', label='IMEX(' + str(rkimex.order) + ')', markevery=(1, 75),
-                 mew=1.0)
-    plt.plot(P.mesh, uend[1, :], 'o-', color='b', label='SDC(' + str(step_params['maxiter']) + ')',
-             markevery=(25, 75))
-    plt.plot(P.mesh, pnew_dirk, '-', color='g', label='DIRK(' + str(dirk_m.order) + ')')
+        plt.plot(
+            P.mesh, pnew_imex, '+-', color='r', label='IMEX(' + str(rkimex.order) + ')', markevery=(1, 75), mew=1.0
+        )
+    plt.plot(P.mesh, uend[1, :], 'o-', color='b', label='SDC(' + str(step_params['maxiter']) + ')', markevery=(25, 75))
+    plt.plot(P.mesh, np.real(pnew_dirk), '-', color='g', label='DIRK(' + str(dirk_m.order) + ')')
 
     plt.xlabel('x', fontsize=fs, labelpad=0)
     plt.ylabel('Pressure', fontsize=fs, labelpad=0)
