@@ -4,6 +4,7 @@ from mpi4py import MPI
 from pySDC.core.Controller import controller
 from pySDC.core.Errors import ControllerError
 from pySDC.core.Step import step
+from pySDC.implementations.convergence_controller_classes.check_convergence import CheckConvergence
 
 import scorep.user as spu
 
@@ -17,13 +18,13 @@ class controller_MPI(controller):
 
     def __init__(self, controller_params, description, comm):
         """
-       Initialization routine for PFASST controller
+        Initialization routine for PFASST controller
 
-       Args:
-           controller_params: parameter set for the controller and the step class
-           description: all the parameters to set up the rest (levels, problems, transfer, ...)
-           comm: MPI communicator
-       """
+        Args:
+            controller_params: parameter set for the controller and the step class
+            description: all the parameters to set up the rest (levels, problems, transfer, ...)
+            comm: MPI communicator
+        """
 
         # call parent's initialization routine
         super(controller_MPI, self).__init__(controller_params)
@@ -56,8 +57,9 @@ class controller_MPI(controller):
                     raise ControllerError("For PFASST to work, we assume uend^k = u_M^k")
 
         if num_levels == 1 and self.params.predict_type is not None:
-            self.logger.warning('you have specified a predictor type but only a single level.. '
-                                'predictor will be ignored')
+            self.logger.warning(
+                'you have specified a predictor type but only a single level.. ' 'predictor will be ignored'
+            )
 
     def run(self, u0, t0, Tend):
         """
@@ -223,9 +225,10 @@ class controller_MPI(controller):
 
             self.hooks.pre_comm(step=self.S, level_number=len(self.S.levels) - 1)
             if not self.S.status.first:
-                self.logger.debug('recv data predict: process %s, stage %s, time, %s, source %s, tag %s' %
-                                  (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                   self.S.status.iter))
+                self.logger.debug(
+                    'recv data predict: process %s, stage %s, time, %s, source %s, tag %s'
+                    % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev, self.S.status.iter)
+                )
                 self.recv(target=self.S.levels[-1], source=self.S.prev, tag=self.S.status.iter, comm=comm)
             self.hooks.post_comm(step=self.S, level_number=len(self.S.levels) - 1)
 
@@ -235,9 +238,10 @@ class controller_MPI(controller):
 
             self.hooks.pre_comm(step=self.S, level_number=len(self.S.levels) - 1)
             if not self.S.status.last:
-                self.logger.debug('send data predict: process %s, stage %s, time, %s, target %s, tag %s' %
-                                  (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                   self.S.status.iter))
+                self.logger.debug(
+                    'send data predict: process %s, stage %s, time, %s, target %s, tag %s'
+                    % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next, self.S.status.iter)
+                )
                 self.S.levels[-1].uend.send(dest=self.S.next, tag=self.S.status.iter, comm=comm)
             self.hooks.post_comm(step=self.S, level_number=len(self.S.levels) - 1, add_to_stats=True)
 
@@ -262,9 +266,10 @@ class controller_MPI(controller):
 
                 self.hooks.pre_comm(step=self.S, level_number=len(self.S.levels) - 1)
                 if not p == 0 and not self.S.status.first:
-                    self.logger.debug('recv data predict: process %s, stage %s, time, %s, source %s, tag %s, phase %s' %
-                                      (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                       self.S.status.iter, p))
+                    self.logger.debug(
+                        'recv data predict: process %s, stage %s, time, %s, source %s, tag %s, phase %s'
+                        % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev, self.S.status.iter, p)
+                    )
                     self.recv(target=self.S.levels[-1], source=self.S.prev, tag=self.S.status.iter, comm=comm)
                 self.hooks.post_comm(step=self.S, level_number=len(self.S.levels) - 1)
 
@@ -274,12 +279,14 @@ class controller_MPI(controller):
 
                 self.hooks.pre_comm(step=self.S, level_number=len(self.S.levels) - 1)
                 if not self.S.status.last:
-                    self.logger.debug('send data predict: process %s, stage %s, time, %s, target %s, tag %s, phase %s' %
-                                      (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                       self.S.status.iter, p))
+                    self.logger.debug(
+                        'send data predict: process %s, stage %s, time, %s, target %s, tag %s, phase %s'
+                        % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next, self.S.status.iter, p)
+                    )
                     self.S.levels[-1].uend.send(dest=self.S.next, tag=self.S.status.iter, comm=comm)
-                self.hooks.post_comm(step=self.S, level_number=len(self.S.levels) - 1,
-                                     add_to_stats=(p == self.S.status.slot))
+                self.hooks.post_comm(
+                    step=self.S, level_number=len(self.S.levels) - 1, add_to_stats=(p == self.S.status.slot)
+                )
 
             # interpolate back to finest level
             for l in range(len(self.S.levels) - 1, 0, -1):
@@ -350,21 +357,23 @@ class controller_MPI(controller):
             self.S.levels[0].sweep.compute_end_point()
 
             if not self.S.status.last and self.params.fine_comm:
-                self.logger.debug('isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s' %
-                                  (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                   0, self.S.status.iter))
+                self.logger.debug(
+                    'isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s'
+                    % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next, 0, self.S.status.iter)
+                )
                 self.req_send[0] = self.S.levels[0].uend.isend(dest=self.S.next, tag=self.S.status.iter, comm=comm)
 
             if not self.S.status.first and not self.S.status.prev_done and self.params.fine_comm:
-                self.logger.debug('recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s' %
-                                  (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                   0, self.S.status.iter))
+                self.logger.debug(
+                    'recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s'
+                    % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev, 0, self.S.status.iter)
+                )
                 self.recv(target=self.S.levels[0], source=self.S.prev, tag=self.S.status.iter, comm=comm)
 
             self.hooks.post_comm(step=self.S, level_number=0)
 
             self.S.levels[0].sweep.compute_residual()
-            self.S.status.done = self.check_convergence(self.S)
+            self.S.status.done = CheckConvergence.check_convergence(self.S)
 
             if self.params.all_to_done:
 
@@ -383,16 +392,25 @@ class controller_MPI(controller):
                 # recv status
                 if not self.S.status.first and not self.S.status.prev_done:
                     self.S.status.prev_done = comm.recv(source=self.S.prev, tag=99)
-                    self.logger.debug('recv status: status %s, process %s, time %s, target %s, tag %s, iter %s' %
-                                      (self.S.status.prev_done, self.S.status.slot, self.S.time, self.S.next,
-                                       99, self.S.status.iter))
+                    self.logger.debug(
+                        'recv status: status %s, process %s, time %s, target %s, tag %s, iter %s'
+                        % (
+                            self.S.status.prev_done,
+                            self.S.status.slot,
+                            self.S.time,
+                            self.S.next,
+                            99,
+                            self.S.status.iter,
+                        )
+                    )
                     self.S.status.done = self.S.status.done and self.S.status.prev_done
 
                 # send status forward
                 if not self.S.status.last:
-                    self.logger.debug('isend status: status %s, process %s, time %s, target %s, tag %s, iter %s' %
-                                      (self.S.status.done, self.S.status.slot, self.S.time, self.S.next,
-                                       99, self.S.status.iter))
+                    self.logger.debug(
+                        'isend status: status %s, process %s, time %s, target %s, tag %s, iter %s'
+                        % (self.S.status.done, self.S.status.slot, self.S.time, self.S.next, 99, self.S.status.iter)
+                    )
                     self.req_status = comm.isend(self.S.status.done, dest=self.S.next, tag=99)
 
                 self.hooks.post_comm(step=self.S, level_number=0, add_to_stats=True)
@@ -445,15 +463,17 @@ class controller_MPI(controller):
                 self.S.levels[0].sweep.compute_end_point()
 
                 if not self.S.status.last and self.params.fine_comm:
-                    self.logger.debug('isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s' %
-                                      (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                       0, self.S.status.iter))
+                    self.logger.debug(
+                        'isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s'
+                        % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next, 0, self.S.status.iter)
+                    )
                     self.req_send[0] = self.S.levels[0].uend.isend(dest=self.S.next, tag=self.S.status.iter, comm=comm)
 
                 if not self.S.status.first and not self.S.status.prev_done and self.params.fine_comm:
-                    self.logger.debug('recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s' %
-                                      (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                       0, self.S.status.iter))
+                    self.logger.debug(
+                        'recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s'
+                        % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev, 0, self.S.status.iter)
+                    )
                     self.recv(target=self.S.levels[0], source=self.S.prev, tag=self.S.status.iter, comm=comm)
 
                 self.hooks.post_comm(step=self.S, level_number=0, add_to_stats=(k == nsweeps - 1))
@@ -486,16 +506,19 @@ class controller_MPI(controller):
                     self.S.levels[l].sweep.compute_end_point()
 
                     if not self.S.status.last and self.params.fine_comm:
-                        self.logger.debug('isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s' %
-                                          (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                           l, self.S.status.iter))
-                        self.req_send[l] = self.S.levels[l].uend.isend(dest=self.S.next, tag=self.S.status.iter,
-                                                                       comm=comm)
+                        self.logger.debug(
+                            'isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s'
+                            % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next, l, self.S.status.iter)
+                        )
+                        self.req_send[l] = self.S.levels[l].uend.isend(
+                            dest=self.S.next, tag=self.S.status.iter, comm=comm
+                        )
 
                     if not self.S.status.first and not self.S.status.prev_done and self.params.fine_comm:
-                        self.logger.debug('recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s' %
-                                          (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                           l, self.S.status.iter))
+                        self.logger.debug(
+                            'recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s'
+                            % (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev, l, self.S.status.iter)
+                        )
                         self.recv(target=self.S.levels[l], source=self.S.prev, tag=self.S.status.iter, comm=comm)
 
                     self.hooks.post_comm(step=self.S, level_number=l)
@@ -518,17 +541,26 @@ class controller_MPI(controller):
             # receive from previous step (if not first)
             self.hooks.pre_comm(step=self.S, level_number=len(self.S.levels) - 1)
             if not self.S.status.first and not self.S.status.prev_done:
-                self.logger.debug('recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s' %
-                                  (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                   len(self.S.levels) - 1, self.S.status.iter))
+                self.logger.debug(
+                    'recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s'
+                    % (
+                        self.S.status.slot,
+                        self.S.status.stage,
+                        self.S.time,
+                        self.S.prev,
+                        len(self.S.levels) - 1,
+                        self.S.status.iter,
+                    )
+                )
                 self.recv(target=self.S.levels[-1], source=self.S.prev, tag=self.S.status.iter, comm=comm)
             self.hooks.post_comm(step=self.S, level_number=len(self.S.levels) - 1)
 
             # do the sweep
             self.hooks.pre_sweep(step=self.S, level_number=len(self.S.levels) - 1)
-            assert self.S.levels[-1].params.nsweeps == 1, \
-                'ERROR: this controller can only work with one sweep on the coarse level, got %s' % \
-                self.S.levels[-1].params.nsweeps
+            assert self.S.levels[-1].params.nsweeps == 1, (
+                'ERROR: this controller can only work with one sweep on the coarse level, got %s'
+                % self.S.levels[-1].params.nsweeps
+            )
             self.S.levels[-1].sweep.update_nodes()
             self.S.levels[-1].sweep.compute_residual()
             self.hooks.post_sweep(step=self.S, level_number=len(self.S.levels) - 1)
@@ -537,9 +569,17 @@ class controller_MPI(controller):
             # send to next step
             self.hooks.pre_comm(step=self.S, level_number=len(self.S.levels) - 1)
             if not self.S.status.last:
-                self.logger.debug('send data: process %s, stage %s, time %s, target %s, tag %s, iter %s' %
-                                  (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                   len(self.S.levels) - 1, self.S.status.iter))
+                self.logger.debug(
+                    'send data: process %s, stage %s, time %s, target %s, tag %s, iter %s'
+                    % (
+                        self.S.status.slot,
+                        self.S.status.stage,
+                        self.S.time,
+                        self.S.next,
+                        len(self.S.levels) - 1,
+                        self.S.status.iter,
+                    )
+                )
                 self.S.levels[-1].uend.send(dest=self.S.next, tag=self.S.status.iter, comm=comm)
             self.hooks.post_comm(step=self.S, level_number=len(self.S.levels) - 1, add_to_stats=True)
 
@@ -573,19 +613,36 @@ class controller_MPI(controller):
                         self.S.levels[l - 1].sweep.compute_end_point()
 
                         if not self.S.status.last and self.params.fine_comm:
-                            self.logger.debug('isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s' %
-                                              (self.S.status.slot, self.S.status.stage, self.S.time, self.S.next,
-                                               l - 1, self.S.status.iter))
-                            self.req_send[l - 1] = self.S.levels[l - 1].uend.isend(dest=self.S.next,
-                                                                                   tag=self.S.status.iter,
-                                                                                   comm=comm)
+                            self.logger.debug(
+                                'isend data: process %s, stage %s, time %s, target %s, tag %s, iter %s'
+                                % (
+                                    self.S.status.slot,
+                                    self.S.status.stage,
+                                    self.S.time,
+                                    self.S.next,
+                                    l - 1,
+                                    self.S.status.iter,
+                                )
+                            )
+                            self.req_send[l - 1] = self.S.levels[l - 1].uend.isend(
+                                dest=self.S.next, tag=self.S.status.iter, comm=comm
+                            )
 
                         if not self.S.status.first and not self.S.status.prev_done and self.params.fine_comm:
-                            self.logger.debug('recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s' %
-                                              (self.S.status.slot, self.S.status.stage, self.S.time, self.S.prev,
-                                               l - 1, self.S.status.iter))
-                            self.recv(target=self.S.levels[l - 1], source=self.S.prev, tag=self.S.status.iter,
-                                      comm=comm)
+                            self.logger.debug(
+                                'recv data: process %s, stage %s, time %s, source %s, tag %s, iter %s'
+                                % (
+                                    self.S.status.slot,
+                                    self.S.status.stage,
+                                    self.S.time,
+                                    self.S.prev,
+                                    l - 1,
+                                    self.S.status.iter,
+                                )
+                            )
+                            self.recv(
+                                target=self.S.levels[l - 1], source=self.S.prev, tag=self.S.status.iter, comm=comm
+                            )
 
                         self.hooks.post_comm(step=self.S, level_number=l - 1, add_to_stats=(k == nsweeps - 1))
 
