@@ -1,6 +1,6 @@
 import numpy as np
 
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.sweeper_classes.generic_implicit import generic_implicit
 
@@ -14,20 +14,22 @@ class controller_matrix_nonMPI(controller_nonMPI):
 
     def __init__(self, num_procs, controller_params, description):
         """
-       Initialization routine for PFASST controller
+        Initialization routine for PFASST controller
 
-       Args:
-           num_procs: number of parallel time steps (still serial, though), can be 1
-           controller_params: parameter set for the controller and the steps
-           description: all the parameters to set up the rest (levels, problems, transfer, ...)
-       """
+        Args:
+            num_procs: number of parallel time steps (still serial, though), can be 1
+            controller_params: parameter set for the controller and the steps
+            description: all the parameters to set up the rest (levels, problems, transfer, ...)
+        """
 
-        assert description['sweeper_class'] is generic_implicit, \
+        assert description['sweeper_class'] is generic_implicit, (
             'ERROR: matrix version will only work with generic_implicit sweeper, got %s' % description['sweeper_class']
+        )
 
         # call parent's initialization routine
-        super(controller_matrix_nonMPI, self).__init__(num_procs=num_procs, controller_params=controller_params,
-                                                       description=description)
+        super(controller_matrix_nonMPI, self).__init__(
+            num_procs=num_procs, controller_params=controller_params, description=description
+        )
 
         self.nsteps = len(self.MS)
         self.nlevels = len(self.MS[0].levels)
@@ -41,15 +43,18 @@ class controller_matrix_nonMPI(controller_nonMPI):
         prob = self.MS[0].levels[0].prob
 
         assert isinstance(self.nspace, int), 'ERROR: can only handle 1D data, got %s' % self.nspace
-        assert [type(level.sweep.coll) for step in self.MS for level in step.levels].count(CollGaussRadau_Right) == \
-            self.nlevels * self.nsteps, 'ERROR: all collocation nodes have to be of Gauss-Radau type'
+        assert [level.sweep.coll.right_is_node for step in self.MS for level in step.levels].count(
+            True
+        ) == self.nlevels * self.nsteps, 'ERROR: all collocation nodes have to be of Gauss-Radau type'
         assert self.nlevels <= 2, 'ERROR: cannot use matrix-PFASST with more than 2 levels'  # TODO: fixme
-        assert [level.dt for step in self.MS for level in step.levels].count(self.dt) == self.nlevels * self.nsteps, \
-            'ERROR: dt must be equal for all steps and all levels'
+        assert [level.dt for step in self.MS for level in step.levels].count(
+            self.dt
+        ) == self.nlevels * self.nsteps, 'ERROR: dt must be equal for all steps and all levels'
         # assert [level.sweep.coll.num_nodes for step in self.MS for level in step.levels].count(self.nnodes) == \
         #     self.nlevels * self.nsteps, 'ERROR: nnodes must be equal for all steps and all levels'
-        assert [type(level.prob) for step in self.MS for level in step.levels].count(type(prob)) == \
-            self.nlevels * self.nsteps, 'ERROR: all probem classes have to be the same'
+        assert [type(level.prob) for step in self.MS for level in step.levels].count(
+            type(prob)
+        ) == self.nlevels * self.nsteps, 'ERROR: all probem classes have to be the same'
 
         assert self.params.predict_type is None, 'ERROR: no predictor for matrix controller yet'  # TODO: fixme
 
@@ -65,11 +70,15 @@ class controller_matrix_nonMPI(controller_nonMPI):
         N = np.zeros((self.nnodes, self.nnodes))
         N[:, -1] = 1
 
-        self.C = np.eye(self.nsteps * self.nnodes * self.nspace) - \
-            self.dt * np.kron(np.eye(self.nsteps), np.kron(Q, A)) - np.kron(E, np.kron(N, np.eye(self.nspace)))
+        self.C = (
+            np.eye(self.nsteps * self.nnodes * self.nspace)
+            - self.dt * np.kron(np.eye(self.nsteps), np.kron(Q, A))
+            - np.kron(E, np.kron(N, np.eye(self.nspace)))
+        )
         self.C = np.array(self.C)
-        self.P = np.eye(self.nsteps * self.nnodes * self.nspace) - \
-            self.dt * np.kron(np.eye(self.nsteps), np.kron(Qd, A))
+        self.P = np.eye(self.nsteps * self.nnodes * self.nspace) - self.dt * np.kron(
+            np.eye(self.nsteps), np.kron(Qd, A)
+        )
         self.P = np.array(self.P)
 
         if self.nlevels > 1:
@@ -96,9 +105,11 @@ class controller_matrix_nonMPI(controller_nonMPI):
             self.Tcf = np.array(np.kron(np.eye(self.nsteps), np.kron(TcfQ, TcfA)))
             self.Tfc = np.array(np.kron(np.eye(self.nsteps), np.kron(TfcQ, TfcA)))
 
-            self.Pc = np.eye(self.nsteps * nnodesc * self.nspace_c) - \
-                self.dt * np.kron(np.eye(self.nsteps), np.kron(Qdc, Ac)) - \
-                np.kron(E, np.kron(Nc, np.eye(self.nspace_c)))
+            self.Pc = (
+                np.eye(self.nsteps * nnodesc * self.nspace_c)
+                - self.dt * np.kron(np.eye(self.nsteps), np.kron(Qdc, Ac))
+                - np.kron(E, np.kron(Nc, np.eye(self.nspace_c)))
+            )
             self.Pc = np.array(self.Pc)
 
         self.u = np.zeros(self.nsteps * self.nnodes * self.nspace)
@@ -122,10 +133,12 @@ class controller_matrix_nonMPI(controller_nonMPI):
         # some initializations and reset of statistics
         uend = None
         num_procs = len(self.MS)
-        self.hooks.reset_stats()
+        for hook in self.hooks:
+            hook.reset_stats()
 
-        assert ((Tend - t0) / self.dt).is_integer(), \
-            'ERROR: dt, t0, Tend were not chosen correctly, do not divide interval to be computed equally'
+        assert (
+            (Tend - t0) / self.dt
+        ).is_integer(), 'ERROR: dt, t0, Tend were not chosen correctly, do not divide interval to be computed equally'
 
         assert int((Tend - t0) / self.dt) % num_procs == 0, 'ERROR: num_procs not chosen correctly'
 
@@ -140,7 +153,8 @@ class controller_matrix_nonMPI(controller_nonMPI):
 
         # call pre-run hook
         for S in self.MS:
-            self.hooks.pre_run(step=S, level_number=0)
+            for hook in self.hooks:
+                hook.pre_run(step=S, level_number=0)
 
         nblocks = int((Tend - t0) / self.dt / num_procs)
 
@@ -157,9 +171,10 @@ class controller_matrix_nonMPI(controller_nonMPI):
 
         # call post-run hook
         for S in self.MS:
-            self.hooks.post_run(step=S, level_number=0)
+            for hook in self.hooks:
+                hook.post_run(step=S, level_number=0)
 
-        return uend, self.hooks.return_stats()
+        return uend, self.return_stats()
 
     def build_propagation_matrix(self, niter):
         """
@@ -192,8 +207,9 @@ class controller_matrix_nonMPI(controller_nonMPI):
 
         # form span and reduce matrices and add to operator
         Tspread = np.kron(np.concatenate([[1] * (self.nsteps * self.nnodes)]), np.eye(self.nspace)).T
-        Tnospread = np.kron(np.concatenate([[1], [0] * (self.nsteps - 1)]),
-                            np.kron(np.ones(self.nnodes), np.eye(self.nspace))).T
+        Tnospread = np.kron(
+            np.concatenate([[1], [0] * (self.nsteps - 1)]), np.kron(np.ones(self.nnodes), np.eye(self.nspace))
+        ).T
         Treduce = np.kron(np.concatenate([[0] * (self.nsteps * self.nnodes - 1), [1]]), np.eye(self.nspace))
 
         if self.MS[0].levels[0].sweep.params.initial_guess == 'spread':
@@ -289,7 +305,8 @@ class controller_matrix_nonMPI(controller_nonMPI):
 
         MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=0, stage='PRE_STEP')
         for S in MS:
-            self.hooks.pre_step(step=S, level_number=0)
+            for hook in self.hooks:
+                hook.pre_step(step=S, level_number=0)
 
         while np.linalg.norm(self.res, np.inf) > self.tol and niter < self.maxiter:
 
@@ -297,42 +314,50 @@ class controller_matrix_nonMPI(controller_nonMPI):
 
             MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=0, stage='PRE_ITERATION')
             for S in MS:
-                self.hooks.pre_iteration(step=S, level_number=0)
+                for hook in self.hooks:
+                    hook.pre_iteration(step=S, level_number=0)
 
             if self.nlevels > 1:
                 for _ in range(MS[0].levels[1].params.nsweeps):
 
                     MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=1, stage='PRE_COARSE_SWEEP')
                     for S in MS:
-                        self.hooks.pre_sweep(step=S, level_number=1)
+                        for hook in self.hooks:
+                            hook.pre_sweep(step=S, level_number=1)
 
                     self.u += self.Tcf.dot(np.linalg.solve(self.Pc, self.Tfc.dot(self.res)))
                     self.res = self.u0 - self.C.dot(self.u)
 
-                    MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=1,
-                                          stage='POST_COARSE_SWEEP')
+                    MS = self.update_data(
+                        MS=MS, u=self.u, res=self.res, niter=niter, level=1, stage='POST_COARSE_SWEEP'
+                    )
                     for S in MS:
-                        self.hooks.post_sweep(step=S, level_number=1)
+                        for hook in self.hooks:
+                            hook.post_sweep(step=S, level_number=1)
 
             for _ in range(MS[0].levels[0].params.nsweeps):
 
                 MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=0, stage='PRE_FINE_SWEEP')
                 for S in MS:
-                    self.hooks.pre_sweep(step=S, level_number=0)
+                    for hook in self.hooks:
+                        hook.pre_sweep(step=S, level_number=0)
 
                 self.u += np.linalg.solve(self.P, self.res)
                 self.res = self.u0 - self.C.dot(self.u)
 
                 MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=0, stage='POST_FINE_SWEEP')
                 for S in MS:
-                    self.hooks.post_sweep(step=S, level_number=0)
+                    for hook in self.hooks:
+                        hook.post_sweep(step=S, level_number=0)
 
             MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=0, stage='POST_ITERATION')
             for S in MS:
-                self.hooks.post_iteration(step=S, level_number=0)
+                for hook in self.hooks:
+                    hook.post_iteration(step=S, level_number=0)
 
         MS = self.update_data(MS=MS, u=self.u, res=self.res, niter=niter, level=0, stage='POST_STEP')
         for S in MS:
-            self.hooks.post_step(step=S, level_number=0)
+            for hook in self.hooks:
+                hook.post_step(step=S, level_number=0)
 
         return MS
