@@ -1,10 +1,11 @@
 import subprocess
+import os
 
 import numpy as np
 from mpi4py import MPI
 
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.helpers.stats_helper import get_sorted
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.problem_classes.AllenCahn_2D_FD import allencahn_fullyimplicit
 from pySDC.implementations.sweeper_classes.generic_implicit import generic_implicit
@@ -28,13 +29,13 @@ def run_variant(variant=None):
 
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-07
-    level_params['dt'] = 1E-03 / 2
+    level_params['restol'] = 1e-07
+    level_params['dt'] = 1e-03 / 2
     level_params['nsweeps'] = 1
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 3
     sweeper_params['initial_guess'] = 'zero'
 
@@ -44,8 +45,8 @@ def run_variant(variant=None):
 
     problem_params['eps'] = 0.04
     problem_params['newton_maxiter'] = 100
-    problem_params['newton_tol'] = 1E-08
-    problem_params['lin_tol'] = 1E-09
+    problem_params['newton_tol'] = 1e-08
+    problem_params['lin_tol'] = 1e-09
     problem_params['lin_maxiter'] = 100
     problem_params['radius'] = 0.25
 
@@ -126,32 +127,35 @@ def run_variant(variant=None):
     uend, stats = controller.run(u0=uinit, t0=t0, Tend=Tend)
 
     # filter statistics by variant (number of iterations)
-    filtered_stats = filter_stats(stats, type='niter')
-
-    # convert filtered statistics to list of iterations count, sorted by process
-    iter_counts = sort_stats(filtered_stats, sortby='time')
+    iter_counts = get_sorted(stats, type='niter', sortby='time')
 
     # compute and print statistics
     niters = np.array([item[1] for item in iter_counts])
 
     if do_print:
         out = '   Mean number of iterations: %4.2f' % np.mean(niters)
-        assert np.mean(niters) <= maxmeaniters, 'ERROR: number of iterations is too high, got %s instead of %s' \
-                                                % (np.mean(niters), maxmeaniters)
+        assert np.mean(niters) <= maxmeaniters, 'ERROR: number of iterations is too high, got %s instead of %s' % (
+            np.mean(niters),
+            maxmeaniters,
+        )
         print(out)
         out = '   Range of values for number of iterations: %2i ' % np.ptp(niters)
         print(out)
-        out = '   Position of max/min number of iterations: %2i -- %2i' % \
-              (int(np.argmax(niters)), int(np.argmin(niters)))
+        out = '   Position of max/min number of iterations: %2i -- %2i' % (
+            int(np.argmax(niters)),
+            int(np.argmin(niters)),
+        )
         print(out)
         out = '   Std and var for number of iterations: %4.2f -- %4.2f' % (float(np.std(niters)), float(np.var(niters)))
         print(out)
 
         print('   Iteration count (nonlinear/linear): %i / %i' % (P.newton_itercount, P.lin_itercount))
-        print('   Mean Iteration count per call: %4.2f / %4.2f' % (P.newton_itercount / max(P.newton_ncalls, 1),
-                                                                   P.lin_itercount / max(P.lin_ncalls, 1)))
+        print(
+            '   Mean Iteration count per call: %4.2f / %4.2f'
+            % (P.newton_itercount / max(P.newton_ncalls, 1), P.lin_itercount / max(P.lin_ncalls, 1))
+        )
 
-        timing = sort_stats(filter_stats(stats, type='timing_run'), sortby='time')
+        timing = get_sorted(stats, type='timing_run', sortby='time')
 
         print('Time to solution: %6.4f sec.' % timing[0][1])
 
@@ -169,15 +173,23 @@ def main():
     run_variant(variant='ml_serial')
     print()
 
-    cmd = "mpirun -np 3 python -c \"from pySDC.projects.parallelSDC.AllenCahn_parallel import *; " \
-          "run_variant(\'sl_parallel\');\""
+    my_env = os.environ.copy()
+    my_env['PYTHONPATH'] = '../../..:.'
+    my_env['COVERAGE_PROCESS_START'] = 'pyproject.toml'
+
+    cmd = (
+        "mpirun -np 3 python -c \"from pySDC.projects.parallelSDC.AllenCahn_parallel import *; "
+        "run_variant(\'sl_parallel\');\""
+    )
     p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True, shell=True)
     p.wait()
     (output, err) = p.communicate()
     print(output)
 
-    cmd = "mpirun -np 3 python -c \"from pySDC.projects.parallelSDC.AllenCahn_parallel import *; " \
-          "run_variant(\'ml_parallel\');\""
+    cmd = (
+        "mpirun -np 3 python -c \"from pySDC.projects.parallelSDC.AllenCahn_parallel import *; "
+        "run_variant(\'ml_parallel\');\""
+    )
     p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True, shell=True)
     p.wait()
     (output, err) = p.communicate()
