@@ -7,7 +7,6 @@ from pySDC.implementations.problem_classes.GeneralizedFisher_1D_FD_implicit impo
 
 # noinspection PyUnusedLocal
 class generalized_fisher_jac(generalized_fisher):
-
     def eval_jacobian(self, u):
         """
         Evaluation of the Jacobian of the right-hand side
@@ -20,8 +19,9 @@ class generalized_fisher_jac(generalized_fisher):
         """
 
         # noinspection PyTypeChecker
-        dfdu = self.A[1:-1, 1:-1] + sp.diags(self.params.lambda0 ** 2 - self.params.lambda0 ** 2 *
-                                             (self.params.nu + 1) * u ** self.params.nu, offsets=0)
+        dfdu = self.A[1:-1, 1:-1] + sp.diags(
+            self.params.lambda0**2 - self.params.lambda0**2 * (self.params.nu + 1) * u**self.params.nu, offsets=0
+        )
 
         return dfdu
 
