@@ -5,12 +5,12 @@ from collections import namedtuple
 import numpy as np
 
 import pySDC.helpers.plot_helper as plt_helper
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.helpers.stats_helper import get_sorted
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
-from pySDC.implementations.problem_classes.AdvectionEquation_1D_FD import advection1d
+from pySDC.implementations.problem_classes.AdvectionEquation_ND_FD import advectionNd
 from pySDC.implementations.problem_classes.GeneralizedFisher_1D_FD_implicit import generalized_fisher
-from pySDC.implementations.problem_classes.HeatEquation_1D_FD import heat1d
+from pySDC.implementations.problem_classes.HeatEquation_ND_FD import heatNd_unforced
 from pySDC.implementations.problem_classes.Van_der_Pol_implicit import vanderpol
 from pySDC.implementations.sweeper_classes.generic_implicit import generic_implicit
 
@@ -20,11 +20,11 @@ ID = namedtuple('ID', ['setup', 'qd_type', 'param'])
 def main():
     # initialize level parameters (part I)
     level_params = dict()
-    level_params['restol'] = 1E-08
+    level_params['restol'] = 1e-08
 
     # initialize sweeper parameters (part I)
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 3
 
     # initialize step parameters
@@ -37,10 +37,12 @@ def main():
 
     # set up list of Q-delta types and setups
     qd_list = ['LU', 'IE', 'IEpar', 'Qpar', 'MIN']
-    setup_list = [('heat', 63, [10.0 ** i for i in range(-3, 3)]),
-                  ('advection', 64, [10.0 ** i for i in range(-3, 3)]),
-                  ('vanderpol', 2, [0.1 * 2 ** i for i in range(0, 10)]),
-                  ('fisher', 63, [2 ** i for i in range(-2, 3)])]
+    setup_list = [
+        ('heat', 63, [10.0**i for i in range(-3, 3)]),
+        ('advection', 64, [10.0**i for i in range(-3, 3)]),
+        ('vanderpol', 2, [0.1 * 2**i for i in range(0, 10)]),
+        ('fisher', 63, [2**i for i in range(-2, 3)]),
+    ]
     # setup_list = [('fisher', 63, [2 * i for i in range(1, 6)])]
 
     # pre-fill results with lists of  setups
@@ -77,10 +79,11 @@ def main():
 
                     problem_params['nu'] = param
                     problem_params['freq'] = 2
+                    problem_params['bc'] = 'dirichlet-zero'  # boundary conditions
 
                     level_params['dt'] = 0.1
 
-                    description['problem_class'] = heat1d
+                    description['problem_class'] = heatNd_unforced
                     description['problem_params'] = problem_params
                     description['level_params'] = level_params  # pass level parameters
 
@@ -89,16 +92,18 @@ def main():
                     problem_params['c'] = param
                     problem_params['order'] = 2
                     problem_params['freq'] = 2
+                    problem_params['type'] = 'center'  # boundary conditions
+                    problem_params['bc'] = 'periodic'  # boundary conditions
 
                     level_params['dt'] = 0.1
 
-                    description['problem_class'] = advection1d
+                    description['problem_class'] = advectionNd
                     description['problem_params'] = problem_params
                     description['level_params'] = level_params  # pass level parameters
 
                 elif setup == 'vanderpol':
 
-                    problem_params['newton_tol'] = 1E-09
+                    problem_params['newton_tol'] = 1e-09
                     problem_params['newton_maxiter'] = 20
                     problem_params['mu'] = param
                     problem_params['u0'] = np.array([2.0, 0])
@@ -114,7 +119,7 @@ def main():
                     problem_params['nu'] = 1
                     problem_params['lambda0'] = param
                     problem_params['newton_maxiter'] = 20
-                    problem_params['newton_tol'] = 1E-10
+                    problem_params['newton_tol'] = 1e-10
                     problem_params['interval'] = (-5, 5)
 
                     level_params['dt'] = 0.01
@@ -128,8 +133,9 @@ def main():
                     exit()
 
                 # instantiate controller
-                controller = controller_nonMPI(num_procs=1, controller_params=controller_params,
-                                               description=description)
+                controller = controller_nonMPI(
+                    num_procs=1, controller_params=controller_params, description=description
+                )
 
                 # get initial values on finest level
                 P = controller.MS[0].levels[0].prob
@@ -139,10 +145,7 @@ def main():
                 uend, stats = controller.run(u0=uinit, t0=0, Tend=level_params['dt'])
 
                 # filter statistics by type (number of iterations)
-                filtered_stats = filter_stats(stats, type='niter')
-
-                # convert filtered statistics to list of iterations count, sorted by process
-                iter_counts = sort_stats(filtered_stats, sortby='time')
+                iter_counts = get_sorted(stats, type='niter', sortby='time')
 
                 # just one time-step, grep number of iteration and store
                 niter = iter_counts[0][1]
@@ -208,8 +211,16 @@ def plot_iterations():
             else:
                 ls = '-'
                 lw = 1
-            plt_helper.plt.semilogx(results[setup][1], niter, label=qd_type, lw=lw, linestyle=ls, color=color,
-                                    marker=marker, markeredgecolor='k')
+            plt_helper.plt.semilogx(
+                results[setup][1],
+                niter,
+                label=qd_type,
+                lw=lw,
+                linestyle=ls,
+                color=color,
+                marker=marker,
+                markeredgecolor='k',
+            )
 
         if setup == 'heat':
             xlabel = r'$\nu$'
