@@ -6,7 +6,6 @@ from pySDC.core.Hooks import hooks
 
 
 class fault_hook(hooks):
-
     def __init__(self):
         """
         Initialization of fault hooks
@@ -39,5 +38,12 @@ class fault_hook(hooks):
 
         L = step.levels[level_number]
 
-        self.add_to_stats(process=step.status.slot, time=L.time, level=L.level_index, iter=step.status.iter,
-                          sweep=L.status.sweep, type='fault_stats', value=L.sweep.fault_stats)
+        self.add_to_stats(
+            process=step.status.slot,
+            time=L.time,
+            level=L.level_index,
+            iter=step.status.iter,
+            sweep=L.status.sweep,
+            type='fault_stats',
+            value=L.sweep.fault_stats,
+        )
