@@ -3,16 +3,19 @@ from __future__ import division
 import dill
 import numpy as np
 
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
+from pySDC.helpers.stats_helper import get_sorted
+
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.problem_classes.GeneralizedFisher_1D_FD_implicit import generalized_fisher
-from pySDC.implementations.problem_classes.HeatEquation_1D_FD import heat1d
+from pySDC.implementations.problem_classes.HeatEquation_ND_FD import heatNd_unforced
 from pySDC.implementations.problem_classes.Van_der_Pol_implicit import vanderpol
 from pySDC.projects.soft_failure.FaultHooks import fault_hook
 from pySDC.projects.soft_failure.implicit_sweeper_faults import implicit_sweeper_faults
-from pySDC.projects.soft_failure.visualization_helper import show_residual_across_simulation, \
-    show_min_max_residual_across_simulation, show_iter_hist
+from pySDC.projects.soft_failure.visualization_helper import (
+    show_residual_across_simulation,
+    show_min_max_residual_across_simulation,
+    show_iter_hist,
+)
 
 
 def diffusion_setup():
@@ -21,23 +24,24 @@ def diffusion_setup():
     """
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-10
+    level_params['restol'] = 1e-10
     level_params['dt'] = 0.25
     level_params['nsweeps'] = 1
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 3
     sweeper_params['QI'] = 'LU'  # For the IMEX sweeper, the LU-trick can be activated for the implicit part
     sweeper_params['initial_guess'] = 'spread'
-    sweeper_params['detector_threshold'] = 1E-10
+    sweeper_params['detector_threshold'] = 1e-10
 
     # initialize problem parameters
     problem_params = dict()
     problem_params['nu'] = 0.1  # diffusion coefficient
     problem_params['freq'] = 4  # frequency for the test value
     problem_params['nvars'] = 127  # number of degrees of freedom for each level
+    problem_params['bc'] = 'dirichlet-zero'  # boundary conditions
 
     # initialize step parameters
     step_params = dict()
@@ -49,7 +53,7 @@ def diffusion_setup():
 
     # fill description dictionary for easy step instantiation
     description = dict()
-    description['problem_class'] = heat1d  # pass problem class
+    description['problem_class'] = heatNd_unforced  # pass problem class
     description['problem_params'] = problem_params  # pass problem parameters
     description['sweeper_class'] = implicit_sweeper_faults  # pass sweeper
     description['sweeper_params'] = sweeper_params  # pass sweeper parameters
@@ -65,24 +69,24 @@ def reaction_setup():
     """
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-10
+    level_params['restol'] = 1e-10
     level_params['dt'] = 0.25
     level_params['nsweeps'] = 1
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 3
     sweeper_params['QI'] = 'LU'  # For the IMEX sweeper, the LU-trick can be activated for the implicit part
     sweeper_params['initial_guess'] = 'spread'
-    sweeper_params['detector_threshold'] = 1E-10
+    sweeper_params['detector_threshold'] = 1e-10
 
     # initialize problem parameters
     problem_params = dict()
     problem_params['nu'] = 1.0
     problem_params['lambda0'] = 2.0
     problem_params['newton_maxiter'] = 20
-    problem_params['newton_tol'] = 1E-10
+    problem_params['newton_tol'] = 1e-10
     problem_params['stop_at_nan'] = False
     problem_params['interval'] = (-5, 5)
     problem_params['nvars'] = 127
@@ -113,20 +117,20 @@ def vanderpol_setup():
     """
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-10
+    level_params['restol'] = 1e-10
     level_params['dt'] = 0.25
     level_params['nsweeps'] = 1
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 3
     sweeper_params['QI'] = 'LU'
-    sweeper_params['detector_threshold'] = 1E-10
+    sweeper_params['detector_threshold'] = 1e-10
 
     # initialize problem parameters
     problem_params = dict()
-    problem_params['newton_tol'] = 1E-10
+    problem_params['newton_tol'] = 1e-10
     problem_params['newton_maxiter'] = 50
     problem_params['stop_at_nan'] = False
     problem_params['mu'] = 18
@@ -185,10 +189,7 @@ def run_clean_simulations(type=None):
     uend, stats = controller.run(u0=uinit, t0=t0, Tend=Tend)
 
     # filter statistics by type (number of iterations)
-    filtered_stats = filter_stats(stats, type='niter')
-
-    # convert filtered statistics to list of iterations count, sorted by process
-    iter_counts = sort_stats(filtered_stats, sortby='time')
+    iter_counts = get_sorted(stats, type='niter', sortby='time')
 
     # print('This clean run took %s iterations!' % iter_counts[0][1])
 
@@ -255,7 +256,7 @@ def process_statistics(type=None, cwd=''):
     minlen = 1000
     nruns = 0
     for stats in results:
-        residuals = sort_stats(filter_stats(stats, type='residual_post_iteration'), sortby='iter')
+        residuals = get_sorted(stats, type='residual_post_iteration', sortby='iter')
         minlen = min(minlen, len(residuals))
         nruns += 1
 
@@ -273,9 +274,9 @@ def process_statistics(type=None, cwd=''):
 
     for stats in results:
         # Some black magic to extract fault stats out of monstrous stats object
-        # fault_stats = sort_stats(filter_stats(stats, type='fault_stats'), sortby='type')[0][1]
+        # fault_stats = get_sorted(stats, type='fault_stats', sortby='type')[0][1]
         # Some black magic to extract residuals dependent on iteration out of monstrous stats object
-        residuals_iter = sort_stats(filter_stats(stats, type='residual_post_iteration'), sortby='iter')
+        residuals_iter = get_sorted(stats, type='residual_post_iteration', sortby='iter')
         # extract residuals ouf of residuals_iter
         residuals = np.array([item[1] for item in residuals_iter])
 
@@ -311,13 +312,14 @@ def process_statistics(type=None, cwd=''):
     # call helper routine to produce residual plot of minres, maxres, meanres and medianres
     # fname = 'min_max_residuals.png'
     fname = cwd + 'data/' + type + '_' + str(nruns) + '_' + 'runs' + '_' + 'min_max_residuals.png'
-    show_min_max_residual_across_simulation(fname=fname, minres=minres, maxres=maxres, meanres=meanres,
-                                            medianres=medianres, maxiter=minlen)
+    show_min_max_residual_across_simulation(
+        fname=fname, minres=minres, maxres=maxres, meanres=meanres, medianres=medianres, maxiter=minlen
+    )
 
     # calculate maximum number of iterations per test run
     maxiter = []
     for stats in results:
-        residuals = sort_stats(filter_stats(stats, type='residual_post_iteration'), sortby='iter')
+        residuals = get_sorted(stats, type='residual_post_iteration', sortby='iter')
         maxiters = max(np.array([item[0] for item in residuals]))
         maxiter.append(maxiters)
     # print(maxiter)
@@ -337,7 +339,7 @@ def process_statistics(type=None, cwd=''):
     # calculate sum of nfaults_detected, sum of nfalse_positives, sum of nfaults_missed
     for stats in results:
         # Some black magic to extract fault stats out of monstrous stats object
-        fault_stats = sort_stats(filter_stats(stats, type='fault_stats'), sortby='type')[0][1]
+        fault_stats = get_sorted(stats, type='fault_stats', sortby='type')[0][1]
         nfd += fault_stats.nfaults_detected
         nfp += fault_stats.nfalse_positives
         nfm += fault_stats.nfaults_missed
