@@ -1,7 +1,8 @@
 import numpy as np
+from pathlib import Path
+
+from pySDC.helpers.stats_helper import get_sorted
 
-from pySDC.helpers.stats_helper import filter_stats, sort_stats
-from pySDC.implementations.collocation_classes.gauss_radau_right import CollGaussRadau_Right
 from pySDC.implementations.controller_classes.controller_nonMPI import controller_nonMPI
 from pySDC.implementations.problem_classes.PenningTrap_3D import penningtrap
 from pySDC.implementations.sweeper_classes.boris_2nd_order import boris_2nd_order
@@ -10,29 +11,32 @@ from pySDC.tutorial.step_3.HookClass_Particles import particle_hook
 
 def main():
     """
-    A simple tets program to retrieve user-defined statistics from a run
+    A simple test program to retrieve user-defined statistics from a run
     """
+    Path("data").mkdir(parents=True, exist_ok=True)
+
     err, stats = run_penning_trap_simulation()
 
     # filter statistics type (etot)
-    filtered_stats = filter_stats(stats, type='etot')
-
-    # sort and convert stats to list, sorted by iteration numbers (only pre- and after-step are present here)
-    energy = sort_stats(filtered_stats, sortby='iter')
+    energy = get_sorted(stats, type='etot', sortby='iter')
 
     # get base energy and show difference
     base_energy = energy[0][1]
-    f = open('step_3_B_out.txt', 'a')
+    f = open('data/step_3_B_out.txt', 'a')
     for item in energy:
-        out = 'Total energy and deviation in iteration %2i: %12.10f -- %12.8e' % \
-              (item[0], item[1], abs(base_energy - item[1]))
+        out = 'Total energy and deviation in iteration %2i: %12.10f -- %12.8e' % (
+            item[0],
+            item[1],
+            abs(base_energy - item[1]),
+        )
         f.write(out + '\n')
         print(out)
     f.close()
 
-    assert abs(base_energy - energy[-1][1]) < 15, 'ERROR: energy deviated too much, got %s' % \
-                                                  (base_energy - energy[-1][1])
-    assert err < 5E-04, "ERROR: solution is not as exact as expected, got %s" % err
+    assert abs(base_energy - energy[-1][1]) < 15, 'ERROR: energy deviated too much, got %s' % (
+        base_energy - energy[-1][1]
+    )
+    assert err < 5e-04, "ERROR: solution is not as exact as expected, got %s" % err
 
 
 def run_penning_trap_simulation():
@@ -41,12 +45,12 @@ def run_penning_trap_simulation():
     """
     # initialize level parameters
     level_params = dict()
-    level_params['restol'] = 1E-08
+    level_params['restol'] = 1e-08
     level_params['dt'] = 1.0 / 16
 
     # initialize sweeper parameters
     sweeper_params = dict()
-    sweeper_params['collocation_class'] = CollGaussRadau_Right
+    sweeper_params['quad_type'] = 'RADAU-RIGHT'
     sweeper_params['num_nodes'] = 3
 
     # initialize problem parameters for the Penning trap
@@ -65,7 +69,7 @@ def run_penning_trap_simulation():
     controller_params = dict()
     controller_params['hook_class'] = particle_hook  # specialized hook class for more statistics and output
     controller_params['log_to_file'] = True
-    controller_params['fname'] = 'step_3_B_out.txt'
+    controller_params['fname'] = 'data/step_3_B_out.txt'
 
     # Fill description dictionary for easy hierarchy creation
     description = dict()
