@@ -22,11 +22,11 @@ class penningtrap_coarse(penningtrap):
         N = self.params.nparts
 
         Emat = np.diag([1, 1, -2])
-        f = self.dtype_f(((3, self.init[0]), self.init[1], self.init[2]), val=0.0)
+        f = self.dtype_f(self.init, val=0.0)
 
         # only compute external forces here: O(N) instead of O(N*N)
         for n in range(N):
-            f.elec[:, n] = self.params.omega_E ** 2 / (part.q[n] / part.m[n]) * np.dot(Emat, part.pos[:, n])
+            f.elec[:, n] = self.params.omega_E**2 / (part.q[n] / part.m[n]) * np.dot(Emat, part.pos[:, n])
             f.magn[:, n] = self.params.omega_B * np.array([0, 0, 1])
 
         return f
